pub(crate) enum SnapshotSignatureState {
UnsignedLocal,
VerifiedEmbedded,
VerifiedTrusted,
}Expand description
Honest signature handling state for the selected build and request.
Variants
UnsignedLocal
No signature was requested or present for local use.
VerifiedEmbedded
The embedded public key verifies the signature.
VerifiedTrusted
The signature verifies against an explicitly trusted public key.